export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);

        this.addInput("ROC1Period", InputType.int, 14);
        this.addInput("ROC2Period", InputType.int, 11);
        this.addInput("MAPeriod", InputType.int, 10);
        this.addInput("strType", InputType.string, "Moving Average Types:");
        this.addInput("strm0", InputType.string, "0=SMA, 1 = EMA");
        this.addInput("strm1", InputType.string, "2=SMMA, 3 = LWMA");
        this.addInput("MAType", InputType.int, 3);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            Coppock : this.addBuffer(),
        };

        this.arr = {
            ROCSum : [],
        };

        this.vars = {
            DrawBegin:0
        };
    }

    onInit() {
        let {ROC1Period, ROC2Period, MAPeriod, MAType} = this.getInputs(),
            shortName, strMAType;

        switch (MAType) {
            case 1:
                strMAType = "EMA";
                break;
            case 2:
                strMAType = "SMMA";
                break;
            case 3:
                strMAType = "LWMA";
                break;
            default:
                strMAType = "SMA";
                break;
        }

        shortName = "Coppock(" + ROC1Period + ", " + ROC2Period + ") " + strMAType + "(" + MAPeriod + ")";
        this.vars.DrawBegin = Math.max(ROC1Period, ROC2Period) + MAPeriod;

        this.buffers.Coppock
            .setShape(Shape.Histogram)
            .setColor(Color.Red)
            .setLabel("Coppock")
            .setShortName(shortName)
           .setDrawBegin(this.vars.DrawBegin)
        ;
    }


    async onUpdate() {
        const {Coppock} = this.buffers,
            {ROCSum} = this.arr,
            {DrawBegin} = this.vars,
            {ROC1Period, ROC2Period, MAPeriod, MAType, PriceType} = this.getInputs(),
            {Close} = await Bar.load([Bar.Mode.Close], PriceType),
            barSize = Close.length;


        let limit, i, counted_bars = Bar.counted();

        if (counted_bars < 0) return (-1);
        if (counted_bars > 0) counted_bars--;
        limit = barSize - counted_bars;
        if (limit - barSize < DrawBegin) {
            limit = barSize - DrawBegin;
        }
        for (i = 0; i < limit; i++) {
            ROCSum[i] = (Close[i] - Close[i + ROC1Period]) / Close[i + ROC1Period] + (Close[i] - Close[i + ROC2Period]) / Close[i + ROC2Period];
        }

        Coppock.fill(Indicators.MAOnArray(ROCSum, 0, MAPeriod, 0, MAType));
    }
}
